import sys
from pathlib import Path
from typing import List

from rich.console import Console
from rich.text import Text

from .configs import ReviewConfig


def create_console() -> Console:
    """Create console instance for colored output."""
    return Console()


def create_error_console() -> Console:
    return Console(stderr=True, style="bold red")


def log_review_start(config: ReviewConfig) -> None:
    console = create_console()
    """Log the start of review process with colored output."""
    console.print(
        f"[bold blue]ReviewLlama[/bold blue] - Starting review of {len(config.paths)} path(s)",
        style="bold",
    )
    console.print(f"[dim]Model:[/dim] [cyan]{config.ollama.model}[/cyan]")
    console.print(f"[dim]Server:[/dim] [cyan]{config.ollama.server_url}[/cyan]")
    console.print()


def log_paths(paths: List[Path]) -> None:
    """Log the paths being reviewed with colored output."""
    console = create_console()
    console.print("[bold]Paths to review:[/bold]")
    for path in paths:
        console.print(f"  • {path}")
    console.print()


def log_error(error: str) -> None:
    """Log error message with colored output."""
    console = create_error_console()
    console.print(f"Error: {error}")
